Stan Math Library: stan/math/prim/scal/err/check_bounded.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Classes | Namespaces | Functions
check_bounded.hpp File Reference
`#include <stan/math/prim/scal/err/domain_error.hpp>`
`#include <stan/math/prim/scal/err/domain_error_vec.hpp>`
`#include <stan/math/prim/scal/meta/max_size.hpp>`
`#include <stan/math/prim/scal/meta/VectorView.hpp>`
`#include <string>`

Go to the source code of this file.

## Classes
struct | stan::math::detail::bounded< T_y, T_low, T_high, y_is_vec >
struct | stan::math::detail::bounded< T_y, T_low, T_high, true >

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.
| stan::math::detail

## Functions
template<typename T_y , typename T_low , typename T_high >
bool | stan::math::check_bounded (const char *function, const char *name, const T_y &y, const T_low &low, const T_high &high)
| Return `true` if the value is between the low and high values, inclusively. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.